libt2n-git Archives

Subject: C++ inter-process communication library branch, master, updated. v0.7-7-ga63e08b

From: libt2n-git@xxxxxxxxxxxxxxxxxxxxxxx
To: libt2n-git@xxxxxxxxxxxxxxxxxxxxxxx
Date: Sat, 23 May 2020 12:37:36 +0200 (CEST)
The branch, master has been updated
       via  a63e08b83794273da3840e0b8bf15bf0085fe3c4 (commit)
      from  c209619c4d44a3e9c5b0f537f53ec65564899efb (commit)


- Log -----------------------------------------------------------------
commit a63e08b83794273da3840e0b8bf15bf0085fe3c4
Author: Thomas Jarosch <thomas.jarosch@xxxxxxxxxxxxx>
Date:   Sat May 23 12:37:34 2020 +0200

    Fix 'occurred' typo

-----------------------------------------------------------------------

Summary of changes:
 src/client_wrapper.hxx |    2 +-
 src/connection.cpp     |    4 ++--
 src/server.cpp         |    4 ++--
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/client_wrapper.hxx b/src/client_wrapper.hxx
index 50d5df6..73fda24 100644
--- a/src/client_wrapper.hxx
+++ b/src/client_wrapper.hxx
@@ -246,7 +246,7 @@ class T2nSingletonWrapper : public 
T2nSingletonWrapperMessages
             if (!WrappedConnection->handle(SingletonObject->Stub.get(),call))
             {
                 // create an result with default-constructor if the handler 
could not
-                // successfully do a call but no exception occured
+                // successfully do a call but no exception occurred
                 result=typename detail::TypeWrap<R>::type();
             }
             return result;
diff --git a/src/connection.cpp b/src/connection.cpp
index f686aa0..6879067 100644
--- a/src/connection.cpp
+++ b/src/connection.cpp
@@ -171,9 +171,9 @@ void connection::add_callback(callback_event_type event, 
const boost::function<v
     callbacks[event].push_back(func);
 }
 
-/** @brief an event has occured, execute the callbacks that are registered for 
this event
+/** @brief an event has occurred, execute the callbacks that are registered 
for this event
 
-    @param event event type that has occured
+    @param event event type that has occurred
 */
 void connection::do_callbacks(callback_event_type event)
 {
diff --git a/src/server.cpp b/src/server.cpp
index 79b95b4..600cbef 100644
--- a/src/server.cpp
+++ b/src/server.cpp
@@ -140,9 +140,9 @@ void server::add_callback(callback_event_type event, const 
boost::function<void
 }
 
 
 /** @brief an event occured, call all server-side callbacks
 
-    @param event event that occured
+    @param event event that occurred
     @param conn_id connection-id parameter that will be given to the 
callback-function
 */
@@ -140,9 +140,9 @@ void server::add_callback(callback_event_type event, const 
 
 
-/** @brief an event occured, call all server-side callbacks
+/** @brief an event occurred, call all server-side callbacks
 
 void server::do_callbacks(callback_event_type event, unsigned int conn_id)


hooks/post-receive
-- 
C++ inter-process communication library

--
libt2n-git - see http://www.intra2net.com/en/developer/libt2n for details.
To unsubscribe send a mail to libt2n-git+unsubscribe@xxxxxxxxxxxxxxxxxxxxxxx   

Current Thread
  • C++ inter-process communication library branch, master, updated. v0.7-7-ga63e08b, libt2n-git <=